Skip to content

Calculates first generation biofuels production, imports, exports for biogas, bioethanol and biodiesel from IEA database. The unit is Petajoule.

Usage

calc1stBioenergyPast()

Value

List of magpie objects with results on country level, weight on country level, unit and description.

Author

Xiaoxi Wang, Isabelle Weindl

Examples

if (FALSE) { # \dontrun{
calcOutput("1stBioenergyPast")
} # }