calcAtmosphericRedepositionShare
Source:R/calcAtmosphericTransboundaryRedepositionShare.R
calcAtmosphericTransboundaryRedepositionShare.RdCalculates share of volatilised nitrogen emissions that is redeposited on different land types.
R/calcAtmosphericTransboundaryRedepositionShare.R
calcAtmosphericTransboundaryRedepositionShare.RdCalculates share of volatilised nitrogen emissions that is redeposited on different land types.