Skip to content

Calculates the supply of agricultural and forestry based biomass that are used in the energy or industry sector

Usage

calcBiomassForNonFood()

Value

List of magpie objects with results on country level, weight on country level, unit and description.

Author

Kristine Karstens

Examples

if (FALSE) { # \dontrun{
calcOutput("calcBiomassForNonFood")
} # }