Skip to content

Calculates the demand of construction wood from Galina et al. 2020 data. See

Usage

calcConstructionWoodDemand()

Value

List of magpie objects with results on country level, weight on country level, unit and description.

Author

Abhijeet Mishra

Examples

if (FALSE) { # \dontrun{
calcOutput("ConstructionWoodDemand")
} # }