Calculate baseline emissions for maccs (mostly) from CEDS2024 data
Source:R/calcEmiMacCEDS.R
calcEmiMacCEDS.RdProvides REMIND data for baseline emissions for maccs from CEDS2024 Note that this can't fully replace the old EDGAR data, as it doesn't include land use CO2 emissions. These are not currently actually used in REMIND by default as the LUC CO2 MACC is off, but it's still not officially deprecated.
Value
REMIND data for baseline emissions for maccs and corresonding weights (NULL) as a list of two MAgPIE objects
Details
Therefore, the CO2 from LUC is read from EDGAR with a 2005, a potentially different baseyear than the one chosen in the parameter