Skip to content

calculates nitrogenous emissions from animal waste management systems in the historical period

Usage

calcEmisNitrogenAWMSPast()

Value

List of magpie object with results on country level, weight on country level, unit and description.

Author

Benjamin Leon Bodirsky

Examples

if (FALSE) { # \dontrun{
calcOutput("EmisNitrogenAWMSPast")
} # }