Calculates nitrogenous emissions from pastures for the historical period
Usage
calcEmisNitrogenPasturePast(method = "IPCC")
Arguments
- method
IPCC: emissions are calculated according the the IPCC 2006 National Guidelines
for Greenhouse Gas Inventories. Nsurplus: Emissions in 2005 are calculated according to IPCC,
and the scaled with nitrogen losses from croplands.
Value
List of magpie object with results on country level, weight on country level, unit and description.
Author
Benjamin Leon Bodirsky
Examples
if (FALSE) { # \dontrun{
calcOutput("EmisNitrogenPasturePast")
} # }