providees an emission inventory for the past, either from external data or own estimates.
Usage
calcEmissionInventory(
datasource = "CEDS",
targetResolution = "sectoral",
from = "CEDS59",
to = "Sectors"
)providees an emission inventory for the past, either from external data or own estimates.
calcEmissionInventory(
datasource = "CEDS",
targetResolution = "sectoral",
from = "CEDS59",
to = "Sectors"
)