Skip to content

Calculates future central feed shares for all livestock categories based on the results of a non-linear regression between historical central feed shares and livestock productivity and using Koeppen- Geiger climate zones

Usage

calcFeedEfficiencyFuture()

Value

Central feed shares and weights as list of two MAgPIE-objects

Author

Isabelle Weindl, Benjamin Bodirsky, Stephen Wirth

Examples

if (FALSE) { # \dontrun{
calcOutput("FeedEfficiencyFuture")
} # }