calculates the crop-specific use of different N inputs
Arguments
- indicator
total: estimates the inputs per total crop production; by_harvest estimates the inputs per ton harvest; by_area estimates the inputs per area harvested
- deposition
if FALSE, deposition is not accounted for in the distribution. Use FALSE to avoid circularities in calcNitrogenBudget
- cellular
cellular disaggreagation or national values
Value
List of magpie objects with results on country level, weight on country level, unit and description.