Skip to content

Calculates food waste and sewage based on the FAO mass balance or future projections from Bodirsky et al. (2018).

Usage

calcFoodWasteAndSewage(historic = TRUE)

Arguments

historic

If set to TRUE only ho

Value

List of magpie objects with results on country level, weight on country level, unit and description.

Author

Benjamin Leon Bodirsky, Xiaoxi Wang

Examples

if (FALSE) { # \dontrun{
calcOutput("FoodWasteAndSewage")
} # }