Skip to content

calculates historic bioplastic production based on data and linear extrapolation

Usage

calcHistBioplasticProd()

Value

List of magpie objects with results on country level, weight on country level, unit and description.

Author

Debbora Leip

Examples

if (FALSE) { # \dontrun{
calcOutput("HistBioplasticProd")
} # }