Skip to content

Distributes crop, pasture and livestock production in space to 0.5 degree

Usage

calcLivestockGridded(details = FALSE)

Arguments

details

switch, if set to TRUE will lead to reporting of extensive and intensive livestock shares

Value

List of magpie objects with results on cellular level, weights on cellular level, unit and description.

Author

Kristine Karstens

Examples

if (FALSE) { # \dontrun{
calcOutput("calcLivestockGridded")
} # }