Skip to content

calculates the share of Manure excreted during grazing which is collected for fuel. For the future, we assume that with the development, the fuel share reaches 0.

Usage

calcManureFuelShr(products = "magpie")

Arguments

products

IPCC: IPCC products. MAgPIE: Magpie products

Value

List of magpie object with results on country level, weight on country level, unit and description.

See also

Author

Benjamin Leon Bodirsky

Examples

if (FALSE) { # \dontrun{
calcOutput("ManureFuelShr")
} # }