Skip to content

Calculates the cellular plantation area based on carbon densities

Usage

calcPlantationCellular()

Value

List of magpie object with results on cellular level, weight on cellular level, unit and description.

Author

Abhijeet Mishra

Examples

if (FALSE) { # \dontrun{
calcOutput("PlantationCellular")
} # }