Skip to content

calculates amount of yearly N from rock weathering by country or global total, disaggregated by land use type (6 classes from LanduseInitialisation)

Usage

calcRockNWeathering()

Value

MAgPIE object of amount of N (Mt)

Author

David M Chen