R/calcWBGEM.R
calcWBGEM.Rd
recover world price of commodity in terms of real 2005 USD per metric ton
calcWBGEM()
magpie object of time series of world price of commodities
madrat::readSource(), readWBGEM()
madrat::readSource()
readWBGEM()
Xiaoxi Wang
if (FALSE) { # \dontrun{ calcOutput("WBGEM") } # }