Skip to content

Reads in regression parameters estimated using mrregression, and reads in some scenario based on Bodirsky et al not yet published

Usage

convertBodirsky2018(x, subtype)

Arguments

x

magpie object from read function

subtype

bmi_share, demand_regression, intake_regression or bodyheight_regression for the estimated regression paramters of different regressions. scenarios for scenario projections.

Value

magpie object