Skip to content

Converts the Data from Herridge et al. to fit the common country list. Source: Herridge D. F., Peoples M. B., Boddey R. M.: Global inputs of biological nitrogen fixation in agricultural systems

Usage

convertHerridge(x)

Arguments

x

MAgPIE object to be converted

Value

A MAgPIE object containing the share of Nr derived from fixation for each country and each commodity.

Author

Stephen Wirth

Examples

if (FALSE) { # \dontrun{
x <- readSource("Herridge")
} # }