Skip to content

It fills the missing values of the output of readLutz2014 through the weighted average of the values of two countries with similar characteristics to the one that has na values.

Usage

convertLutz2014(x)

Arguments

x

magpie object provided by the read function

See also