Skip to content

Downloads the latest data and meta data form the Eurostat website.

Usage

downloadEurostatLivestock(subtype)

Arguments

subtype

Type of Eurostat Livestock data that should be read.