Skip to content

Read in EUROSTAT livestock data

Usage

readEurostatLivestock(subtype)

Arguments

subtype

Type of FAO data that should be read. Available types are:

  • EggPopProd : Production of eggs for consumption and number of laying hens

  • LayingHensPop : Laying hens population - annual data

  • PoultryPop : Poultry - annual data

  • PigPop : Pig population - annual data

  • BovinePop : Bovine population - annual data

  • Nuts2Pop : Animal populations by NUTS 2 regions

  • MeatProd : Meat production and foreign trade - head - monthly data

  • MilkNuts2Prod : Production of cow's milk on farms by NUTS 2 regions

  • MilkProd : Production and utilization of milk on the farm - annual data

Value

EUROSTAT livestock data as MAgPIE object

Author

David Hötten

Examples

if (FALSE) { # \dontrun{
a <- readSource("EurostatLivestock", "MeatProd")
} # }