Skip to content

Read in csv file containing coefficients of non-linear regression analysis for the calculation of future feed efficiencies of feed baskets dependent on livestock productivity trends

Usage

readFeedEfficiencyReg()

Value

MAgPIE object containing regression coefficients

Author

Isabelle Weindl

Examples

if (FALSE) { # \dontrun{
a <- readSource("FeedEfficiencyReg")
} # }