Skip to content

Read in csv file containing coefficients of non-linear regression analysis for the calculation of future central feed shares in feed baskets dependent on livestock productivity trends

Usage

readFeedShareReg()

Value

MAgPIE object containing regression coefficients

Author

Isabelle Weindl

Examples

if (FALSE) { # \dontrun{
a <- readSource("FeedShareReg")
} # }