Skip to content

Read-in a file containing the allometric coeffizients of MAgPIE crop types. Values are assembled from various literature sources, and the weighting and allocation is done in the spreadsheet crop_specifications_*.ods for different versions of the file

Usage

readHI()

Value

magpie object with the dimension crops and coeffizients

Author

Benjamin Leon Bodrisky, Kristine Karstens

Examples

if (FALSE) { # \dontrun{
a <- readSource("HI")
} # }