Skip to content

Read-in world prices data csv file as magclass object

Usage

readIMPACT3.2.2World_Price()

Value

magpie object of the world prices from the IMPACT model for different SSP scenarios

Author

Mishko Stevanovic

Examples

if (FALSE) { # \dontrun{
a <- readSource(type = "IMPACT3.2.2World_Price")
} # }