reads data on historic bioplastic production from csv source: "Biopolymers facts and statistics 2021" page 58, Institute for Bioplastics and Biocomposites (IfBB)
reads data on historic bioplastic production from csv source: "Biopolymers facts and statistics 2021" page 58, Institute for Bioplastics and Biocomposites (IfBB)