Skip to content

Read-in Future trends in first generation bioenergy demand from the publication Lotze Campen et al. 2014. "Impacts of increased bioenergy demand on global food markets: an AgMIP economic model intercomparison" Agricultural Economics 45 (103-116). doi:10.1111/agec.12092. from a .csv file to a magclass object

Usage

readLotzeCampenBiofuel()

Value

Future trends in first generation bioenergy demand in ExaJoule as magpie object

Author

Ewerton Araujo

Examples

if (FALSE) { # \dontrun{
a <- readSource("LotzeCampenBiofuel")
} # }