Skip to content

Reads geospatial data from 'the nature conservancy' on ecoregions, major habitat types (MHT, or biome types) and biogeographic realms.

Usage

readTNC2019()

Value

Returns magpie object with a share of each spatial unit belonging to a biogeographic realm and major habitat type.

Author

Patrick v. Jeetze

Examples

if (FALSE) { # \dontrun{
readSource("TNC2019", convert = "onlycorrect")
} # }