Skip to content

tool function to calculate the share of manure managed in different animal waste management systems in confinements.

Usage

toolAWMSScenarioCreation(name, startYear, categories, values, out)

Arguments

name

Name of the scenario

startYear

Year were prediction starts

categories

share of manure managed in different animal waste management systems

values

target values

out

contains historical data

Value

List of magpie objects with results on country level, weight on country level, unit and description.

Author

Edna J. Molina Bacca