Calculates the supply of agricultural and forestry based biomass
that are used in the energy or industry sector
Value
List of magpie objects with results on country level, weight on country level, unit and description.
Examples
if (FALSE) { # \dontrun{
calcOutput("calcBiomassForNonFood")
} # }