R/calcConstructionWoodDemand.R
calcConstructionWoodDemand.Rd
Calculates the demand of construction wood from Galina et al. 2020 data. See
calcConstructionWoodDemand()
List of magpie objects with results on country level, weight on country level, unit and description.
mrfaocore::calcFAOmassbalance_pre()
Abhijeet Mishra
if (FALSE) { # \dontrun{ calcOutput("ConstructionWoodDemand") } # }