calcEmisNitrogenCroplandPast
Source:R/calcEmisNitrogenCroplandPast.R
calcEmisNitrogenCroplandPast.Rdcalculates nitrogenous emissions from croplands in the historical period.
R/calcEmisNitrogenCroplandPast.R
calcEmisNitrogenCroplandPast.Rdcalculates nitrogenous emissions from croplands in the historical period.