R/calcFoodWasteAndSewage.R
calcFoodWasteAndSewage.Rd
Calculates food waste and sewage based on the FAO mass balance or future projections from Bodirsky et al. (2018).
calcFoodWasteAndSewage(historic = TRUE)
If set to TRUE only ho
List of magpie objects with results on country level, weight on country level, unit and description.
calcFAOmassbalance()
Benjamin Leon Bodirsky, Xiaoxi Wang
if (FALSE) { # \dontrun{ calcOutput("FoodWasteAndSewage") } # }