calculates historic bioplastic production based on data and linear extrapolation
Value
List of magpie objects with results on country level, weight on country level, unit and description.
Examples
if (FALSE) { # \dontrun{
calcOutput("HistBioplasticProd")
} # }