Provides livestock yields for historical and future years.
Usage
calcLivestockProductivity(future = TRUE)
Arguments
- future
if TRUE calculates constant future and linear trends based on SSP Expert guesses
Value
List of magpie objects with results on country level, weight on country level, unit and description.
Author
Isabelle Weindl, Lavinia Baumstark, Stephen Wirth
Examples
if (FALSE) { # \dontrun{
calcOutput("LivestockProductivity")
} # }