Nutrient Budget for Wastewater treatment and sewage
Usage
calcNutrientBudgetSewage(historic = TRUE)
Arguments
- historic
when TRUE only for the historic period, otherwise including future scenarios
Value
List of magpie objects with results on country level, weight on country level, unit and description.
Author
Benjamin Leon Bodirsky
Examples
if (FALSE) { # \dontrun{
calcOutput("NutrientBudgetSewage")
} # }