R/calcPlantationCellular.R
calcPlantationCellular.Rd
Calculates the cellular plantation area based on carbon densities
calcPlantationCellular()
List of magpie object with results on cellular level, weight on cellular level, unit and description.
Abhijeet Mishra
if (FALSE) { # \dontrun{ calcOutput("PlantationCellular") } # }