Calculate historical distribution of livestock production across different systems based on output of MAgPIE_FEED model
Source:R/calcProdSysRatioPast.R
calcProdSysRatioPast.RdCalculate historical distribution of livestock production across different systems based on output of MAgPIE_FEED model
Value
Historical distribution of livestock production across different systems and corresponding weights as a list of two MAgPIE objects