Convert production system distribution and feed basket data to ISO country level.
Usage
convertFeedModel(x, subtype = "FeedBaskets")
Arguments
- x
MAgPIE object containing production system distribution and feed basket data.
- subtype
Available subtypes: "ProdSysRatio", "FeedBaskets" and "FeedBasketsDetailed"
Value
Production system distribution and feed basket data as MAgPIE object on ISO country level
Author
Isabelle Weindl, Jan Philipp Dietrich