R/convertLutz2014.R
convertLutz2014.Rd
It fills the missing values of the output of readLutz2014 through the weighted average of the values of two countries with similar characteristics to the one that has na values.
convertLutz2014(x)
magpie object provided by the read function
readLutz2014()