Read in EUROSTAT livestock data
Arguments
- subtype
Type of FAO data that should be read. Available types are:
EggPopProd: Production of eggs for consumption and number of laying hensLayingHensPop: Laying hens population - annual dataPoultryPop: Poultry - annual dataPigPop: Pig population - annual dataBovinePop: Bovine population - annual dataNuts2Pop: Animal populations by NUTS 2 regionsMeatProd: Meat production and foreign trade - head - monthly dataMilkNuts2Prod: Production of cow's milk on farms by NUTS 2 regionsMilkProd: Production and utilization of milk on the farm - annual data