Read in regression coefficients for feed efficiency
Source:R/readFeedEfficiencyReg.R
readFeedEfficiencyReg.RdRead in csv file containing coefficients of non-linear regression analysis for the calculation of future feed efficiencies of feed baskets dependent on livestock productivity trends