Read in regression coefficients for central feed shares
Source:R/readFeedShareReg.R
readFeedShareReg.RdRead in csv file containing coefficients of non-linear regression analysis for the calculation of future central feed shares in feed baskets dependent on livestock productivity trends