readNitrogenBoundariesGridded
Source:R/readNitrogenBoundariesGridded.R
readNitrogenBoundariesGridded.RdRead the grid-level regional nitrogen boundary datasets from Schulte-Uebbing et al. (2022). For the moment, this only uses the critical N surplus in all agricultural land (arable + intensively managed grassland) in view of all thresholds simultaneously, measured in kg N per ha per yr.