We assume that below a given GDP/cap level, all biomass is traditional and above a higher limit, all biomass is modern with a linear transition between the limits.
Arguments
- x
MagPIE object including biomass data
- gdppop
MagPIE object with GDP/cap data
- split
character, name of item to split
- into
character vector of length two with the names of the split items
- dim
dimension of
xwith the item to split- limits
numeric vector of length two with the corresponding GDP/cap limits. The default values used to be 10k and 15k USD/cap converted from 2005 to 2017 dollars.